<?php

namespace Drupal\hijri_dates\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Hijri Dates settings.
 */
class HijriDatesSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'hijri_dates.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'hijri_dates_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('hijri_dates.settings');

    $form['global_date_correction'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Global date correction'),
      '#description' => $this->t('Enter a PHP date string modifier (e.g., "+1 day", "-2 days", "+3 months") to adjust Hijri dates based on moon sighting or regional variations. These are standard PHP relative date formats. Leave empty for no correction.'),
      '#default_value' => $config->get('global_date_correction') ?: '',
      '#size' => 20,
      '#maxlength' => 30,
    ];

    $form['use_global_correction'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use global correction by default'),
      '#description' => $this->t('When enabled, all Hijri date formatters will use the global correction setting by default unless overridden at the field level.'),
      '#default_value' => $config->get('use_global_correction') ?: TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('hijri_dates.settings')
      ->set('global_date_correction', $form_state->getValue('global_date_correction'))
      ->set('use_global_correction', $form_state->getValue('use_global_correction'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
